{% extends "templates/admin.html" %}

{% block main %}
<div class="container groupslist-menuitem">
<p><a href="{{base_url}}groupslist">&gt; Manage Groups</a></p>
</div>

{{ super() }}
{% endblock %}

