{% extends "templates/page.html" %}

{% block nav_bar_left_items %}

<li><a href="{{base_url}}home-cds">Home</a></li>
<li><a href="{{base_url}}token">Token</a></li>

{% if user.admin %}
<li><a href="{{base_url}}admin">Admin</a></li>
{% endif %}

{% if services %}
<li class="dropdown">
    <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false">Services<span class="caret"></span></a>
    <ul class="dropdown-menu">
    {% for service in services %}
    <li><a class="dropdown-item" href="{{service.prefix}}">{{service.name}}</a></li>
    {% endfor %}
    </ul>
</li>
{% endif %}

<li><a href="{{base_url}}dashboards">Dashboards</a></li>

{% endblock %}

{% block stylesheet %}
<meta http-equiv="Content-Language" content="en">
<link rel="stylesheet" href="{{base_url}}dashboards-static/css/style.css" type="text/css" />
{{ super() }}

{% endblock %}
