
.error {
    color: red;
}

.dashboard-buttons {
    margin-top: 30px;
}

.dashboard-edit-form input[type="text"] {
    width: 300px;
}

.dashboard-edit-form textarea {
    width: 300px;
    height: 60px;
}

.dashboard-edit-form {
    margin-bottom: 20px;
}

#help-floater {
    position: fixed;
    bottom: 20px;
    right: 30px;
    z-index: 99;
    font-size: 18px;
    border: none;
    outline: none;
    background-color: lightblue;
    color: white;
    cursor: pointer;
    padding: 15px;
    border-radius: 4px;
    text-decoration: none;
}

.dashboard-tab-container {
    padding: 5px 0px;
}

ul.dashboard-selectable-tabs {
    padding-inline-start: 0px;
    margin: 20px 5px;
}

ul.dashboard-selectable-tabs li {
    display: inline;
    border: 1px dotted grey;
    padding: 5px 20px;
}

ul.dashboard-selectable-tabs li.active {
    border: 1px solid black;
    background-color: #f0ad4e;
}

.dashboard-tab-container > div {
    margin-left: 20px;
}

.groupslist-menuitem p {
    text-align: right;
}